@@ -317,10 +317,21 @@ class SimulationParams(
         else:
             mpi_params_name = "mpiParameters"
 
-        if args.pele_mpi_params is not None and args.pele_mpi_params != "":
-            self.pele_mpi_params = f'"{mpi_params_name}": "{args.pele_mpi_params}",'
+        # Adaptive needs a json-like string for pele_mpi_params
+        # Frag needs the direct parameter string for pele_mpi_params
+        if not self.frag_pele:
+            if (args.pele_mpi_params is not None and
+                    args.pele_mpi_params != ""):
+                self.pele_mpi_params = \
+                    f'"{mpi_params_name}": "{args.pele_mpi_params}",'
+            else:
+                self.pele_mpi_params = ""
         else:
-            self.pele_mpi_params = ""
+            if (args.pele_mpi_params is not None and
+                    args.pele_mpi_params != ""):
+                self.pele_mpi_params = args.pele_mpi_params
+            else:
+                self.pele_mpi_params = ""
 
     def optative_params(self, args):
         if args.forcefield is None:
@@ -357,8 +368,8 @@ class SimulationParams(
         self.test = args.test
         # +1 to avoid being 0
         self.equil_steps = (
-            int(args.eq_steps / self.cpus) + 1
-            if args.eq_steps
+            args.eq_steps
+            if args.eq_steps is not None
             else self.simulation_params.get("equilibration_steps", 1)
         )
         self.equilibration = (
