@@ -301,6 +301,9 @@ class Analysis(object):
         if "Binding Energy" in metrics:
             t_energy = "currentEnergy"
             i_energy = "Binding Energy"
+        elif "BindingEnergy" in metrics:  # Support new PELE beta
+            t_energy = "currentEnergy"
+            i_energy = "BindingEnergy"
         else:
             t_energy = "currentEnergy"
             i_energy = None
@@ -1216,6 +1219,10 @@ class Analysis(object):
             energy = "Binding Energy"
             plotter.plot_clusters("currentEnergy", energy,
                                   output_folder=path, clusters=clusters)
+        elif "BindingEnergy" in metrics:  # Support new PELE beta
+            energy = "BindingEnergy"
+            plotter.plot_clusters("currentEnergy", energy,
+                                  output_folder=path, clusters=clusters)
         else:
             energy = "currentEnergy"
 
