@@ -11,6 +11,8 @@ PELE_EXEC = os.environ.get("PELE_EXEC", "")
 PELE_DATA = os.environ.get("PELE_DATA", "")
 PELE_DOCUMENTS = os.environ.get("PELE_DOCUMENTS", "")
 PELE_LICENSE = os.environ.get("PELE_LICENSE", "")
+PELE_MPI_PARAMS = os.environ.get("PELE_MPI_PARAMS", "")
+
 DEFAULT_PELE_EXEC = (
     # Priority for the default pele_exec variable:
     #    1. Environment variable (PELE_EXEC)
@@ -44,6 +46,8 @@ DEFAULT_PELE_LICENSE = (
     else os.path.join(PELE, "licenses")
 )
 
+DEFAULT_PELE_MPI_PARAMS = PELE_MPI_PARAMS if PELE_MPI_PARAMS else ""
+
 # DEFAULTS
 # --------
 
@@ -59,29 +63,21 @@ CLUSTERS = 40
 PLATFORM_RESTART = "all"
 EQ_STEPS = 50
 GRIDRES = "10.0"
-NATIVE = """
+NATIVE = """\n
                                    {{
        
                                       "type": "rmsd",
-       
                                       "Native": {{\n\
                                        "path":\n\
                                        "{}" }},\n\
-       
                                       "selection": {{ "chains": {{ "names": [ "{}" ] }} }},\n\
-       
                                       "includeHydrogens": false,\n\
-       
                                       "doSuperposition": false,\n\
-       
                                       "tag" : "ligandRMSD"\n\
-       
                                    }},\n\
-       
-       
             """
 
-WATER_ENERGY = """
+WATER_ENERGY = """\n
                             {{
                             "type": "bindingEnergy",\n\
                             "boundPartSelection": {{ "chains": {{ "names": ["{0}"] }} }},\n\
@@ -89,7 +85,7 @@ WATER_ENERGY = """
                             }},\n\
                            """
 
-UNBINDING = """
+UNBINDING = """\n
             "modeMovingBox" : "unbinding",
             "exitCondition" : {{
                 "type" : "metricMultipleTrajectories",
@@ -102,10 +98,10 @@ UNBINDING = """
             }},
             """
 
-DISTANCE_ATOMS = """
+DISTANCE_ATOMS = """\n
                      {{
                      "type":"com_distance",
-                     "tag":"distance{metric_name}",
+                     "tag":"{metric_name}",
                      "selection_group_1":{{
                      "{atom1_tag}": {{ "ids":["{atom1}"]}}
                      }},
@@ -115,7 +111,7 @@ DISTANCE_ATOMS = """
                      }},
                      """
 
-LOCAL_NONBONDING_ENERGY = """
+LOCAL_NONBONDING_ENERGY = """\n
                      {{
                      "type": "localNonBondingEnergy",
                      "selection": {{ "links": {{ "ids": ["{}"] }} }},
@@ -123,7 +119,7 @@ LOCAL_NONBONDING_ENERGY = """
                       }},
 """
 
-DISTANCE_ATOMS_TAG = """
+DISTANCE_ATOMS_TAG = """\n
                      {{
                      "type":"com_distance",
                      "tag":"{0}",
@@ -136,7 +132,7 @@ DISTANCE_ATOMS_TAG = """
                      }},
                      """
 
-ANGLE_ATOMS_TAG = """
+ANGLE_ATOMS_TAG = """\n
                      {{
                      "type":"atomsAngle",
                      "tag":"{0}",
@@ -152,8 +148,7 @@ ANGLE_ATOMS_TAG = """
                      }},
                      """
 
-BOX = """
-
+BOX = """\n
                 "Box": {{
                     "type": "sphericalBox",
                     "radius": {0},
@@ -161,7 +156,7 @@ BOX = """
                 }},
 """
 
-WATER = """
+WATER = """\n
          "WaterPerturbation":
          {{
              "watersToPerturb": {{ "links": {{ "ids": [ {} ] }} }},
@@ -177,9 +172,9 @@ WATER = """
          }}, 
 """
 
-PCA = """"preloadedModesIn" : "{}","""
+PCA = """\n\t\t\t"preloadedModesIn" : "{}","""
 
-SIDECHAIN_PERTURBATION = """
+SIDECHAIN_PERTURBATION = """\n
          "SideChainPerturbation":{
                         "sideChainsToPerturb": { "links": {"ids": ["$COVALENT_RESIDUE"] } },
                         "parameters":{
@@ -196,7 +191,7 @@ SELECTION_TO_PERTURB = (
     '"selectionToPerturb" : { "chains" : { "names" : [ "$CHAIN" ] } },'
 )
 
-PERTURBATION = """
+PERTURBATION = """\n
           "Perturbation": {
                 $BOX
                 "perturbationType":"naive",
@@ -206,11 +201,11 @@ PERTURBATION = """
                     "numberOfStericTrials": $STERIC_TRIALS,
                     "steeringUpdateFrequency": $STEERING,
                     "overlapFactor": $OVERLAP
-                }   
-                
+                }          
             },
 """
-CONFORMATION_PERTURBATION = '''
+
+CONFORMATION_PERTURBATION = '''\n
         "ConformationPerturbation":{
             "parameters": {
                 "overlapFactor": $OVERLAP_CONFORMATION
@@ -218,37 +213,28 @@ CONFORMATION_PERTURBATION = '''
         },
 '''
 
-BE = """
+BE = """\n
                         { "type": "bindingEnergy",
-
                            "boundPartSelection": { "chains": { "names": ["$CHAIN"] } }
-
                         },
 """
 
-SASA = """
+SASA = """\n
                         { "type": "sasa",
-
                            "tag": "sasaLig",
-
                            "selection": { "chains": { "names": ["$CHAIN"] } }
-
                         },
 """
 
-SASA_COVALENT = """
+SASA_COVALENT = """\n
                         {{ "type": "sasa",
-
                            "tag": "sasaLig",
-
                            "selection": {{ "links": {{ "ids": ["{}"] }} }}
-
                         }},
 """
 
 INTERACTION_RESTRICTIONS = """
-,
-
+\n,
 "interactionRestrictions":
 [
 	"{0}"
@@ -495,7 +481,7 @@ in_pele_data = ["caz", "clz", "cuiz", "cuz", "hohz", "mgz", "mnz", "naz", "spcz"
 
 refinement_angle = '"refinementAngle": {},'
 
-CONFORMATION_FREQUENCY = '"conformationPerturbationFrequency": {},'
+CONFORMATION_FREQUENCY = '\n"conformationPerturbationFrequency": {},'
 
 version_header = """
 PELE Platform {}
@@ -509,4 +495,18 @@ PELE Platform Plotter {}
 -------------------------
 Nostrum Biodiscovery SL
 All rights reserved, 2021.
-"""
\ No newline at end of file
+"""
+
+converter_version_header = """
+PELE Platform Converter {}
+---------------------------
+Nostrum Biodiscovery SL
+All rights reserved, 2021.
+"""
+
+pathway_extractor_version_header = """
+PELE Platform Pathway Extractor {}
+-----------------------------------
+Nostrum Biodiscovery SL
+All rights reserved, 2021.
+"""
